==> spip_4.2.9+dfsg.orig.tar.xz: plugins-dist/porte_plume/lang/barreoutils_fa.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/barreoutils?lang_cible=fa
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'barre_a_accent_grave' => 'گنجاندن يك A بزرگ با آكسان گراو',
	'barre_adresse' => 'آدرس',
	'barre_aide' => 'استفاده از ميان‌برهاي حروف‌نگاري براي بهبود صفحه‌آرايي ',
	'barre_alignerdroite' => 'پارگراف [/راست‌چين/]',
	'barre_ancres' => 'مديريت نقطه‌ لنگر‌ها',
	'barre_barre' => 'خط زدن متن ',
	'barre_bulle' => 'ابزار نكته',
	'barre_c_cedille_maj' => 'گنجانن يك C سدي بزرگ',
	'barre_cadre' => 'قرار دادن يك <cadre>جاي متن </cadre>',
	'barre_caracteres' => 'كاراكتر‌هاي ويژه',
	'barre_centrer' => 'پارگراف [[وسط چين]]',
	'barre_chercher' => 'جستجوي جايگزين',
	'barre_clean' => 'پاك كردن كد تمام برچسب‌هاي اچ.تي.ام.ال',
	'barre_code' => 'تبديل به فرم <code>كد انفورماتيك</code>',
	'barre_desindenter' => 'حذف تورفتگي‌ يك فهرست',
	'barre_e_accent_aigu' => 'گنحاندن يك E بزرگ با آكسان اگو',
	'barre_e_accent_grave' => 'گنجاندن يك E بزرگ با آكسان گراو',
	'barre_ea' => 'گنجاندن يك E در يك A',
	'barre_ea_maj' => 'گنجاندن يك E در يك  A بزرگ',
	'barre_encadrer' => '[(در كادر گذاري)] پارگراف',
	'barre_eo' => 'گنجاندن يك E در يك I',
	'barre_eo_maj' => 'گنجاندن يكE در يك O',
	'barre_euro' => 'گنحاندن سمبل €',
	'barre_exposant' => 'گذاشتن متن در<sup> انديس بالا </sup>',
	'barre_formatages_speciaux' => 'فرمت سازي ويژه',
	'barre_galerie' => 'باز كردن گالري',
	'barre_gestion_anc_bulle' => 'ابزار نكته‌ي ديگر',
	'barre_gestion_anc_caption' => 'مديريت نقطه‌ لنگرها',
	'barre_gestion_anc_cible' => 'نقطه لنگر هدف',
	'barre_gestion_anc_inserer' => 'نبديل به نقطه لنگر',
	'barre_gestion_anc_nom' => 'نام نقطه لنگر',
	'barre_gestion_anc_pointer' => 'اشاره به يك نقطه لنگر ',
	'barre_gestion_caption' => 'شرح و خلاصه',
	'barre_gestion_colonne' => 'شماره ستون‌ها',
	'barre_gestion_cr_casse' => 'تطابق حالت',
	'barre_gestion_cr_changercasse' => 'تغيير حالت',
	'barre_gestion_cr_changercassemajuscules' => 'تبديل به حرف بزرگ ',
	'barre_gestion_cr_changercasseminuscules' => 'تبديل به حرف بزرگ',
	'barre_gestion_cr_chercher' => 'جستجو',
	'barre_gestion_cr_entier' => 'كلمه‌ي كامل ',
	'barre_gestion_cr_remplacer' => 'جايگزيني',
	'barre_gestion_cr_tout' => 'جايگزيني همه',
	'barre_gestion_entete' => 'سرصفحه',
	'barre_gestion_ligne' => 'بدون پيوند',
	'barre_gestion_taille' => 'اندازه ثابت ',
	'barre_glossaire' => 'مدخل [فرهنگ لغت؟] (ويكيپديا)',
	'barre_gras' => '{{بولد}} سازي',
	'barre_guillemets' => 'در «گيومه» گذاشتن',
	'barre_guillemets_simples' => 'در "تك گيومه" گذاشتن',
	'barre_indenter' => 'تورفتگي يك فهرست',
	'barre_inserer_cadre' => 'كنجاندن يك كد پيش فرمت شده  (cadre)', # MODIF
	'barre_inserer_caracteres' => 'گنجاندن كارآكتر‌هاي ويژه',
	'barre_inserer_code' => 'گنحاندن يك كد افنورماتيك (code)', # MODIF
	'barre_intertitre' => 'تبديل به {{ميان‌تيتر}}',
	'barre_italic' => '{{ايرانيك}}سازي',
	'barre_langue' => 'زبان اختصاري',
	'barre_lien' => 'تبديل به [پيوند هايپرتكس ->http://...[',
	'barre_lien_externe' => 'پيوند بيروني',
	'barre_lien_input' => 'لطفاً نشاني پيوند خود را وارد كنيد (مي‌توانيد يك نشاني اينترنت با فرمت http://www.monsite.com وارد كنيد، يا يك نشاني ايميل، يا خيلي ساده، شماره‌ي مقاله‌ي اين سايت را وارد كنيد). ',
	'barre_liste_ol' => 'تبيدل يه ليست شماره دار',
	'barre_liste_ul' => 'تبديل به فهرست كردن',
	'barre_lorem_ipsum' => 'گنجاندن يك پارگراف بدلي ',
	'barre_lorem_ipsum_3' => 'گنجاندن سه پارگراف بدلي ',
	'barre_miseenevidence' => 'پررنگ ‌سازي*] متن*] ',
	'barre_note' => 'تبديل به [[پانويس]]',
	'barre_paragraphe' => 'ايجاد يك پارگراف',
	'barre_petitescapitales' => 'تبديل متن به  <sc>حروف كاپيتال كوچك</sc>',
	'barre_poesie' => 'ويرايش به مانند  <شعر>شعر</شعر>',
	'barre_preview' => 'حالت پيش‌نمايش ',
	'barre_quote' => '<quote>نقل قول</quote>',
	'barre_stats' => 'نمايش آمارهاي متن ',
	'barre_tableau' => 'گنحاندن/اصلاح كردن (انتخاب از پيش) يك جدول ',

	// C
	'config_info_enregistree' => 'پيكربندي ثبت شده',

	// E
	'editer' => 'ويرايش',
	'explication_barre_outils_public' => 'سي.اس.اس و جاوااسكريپتز براي نوار ابزارها (چوب قلم) در صفحه‌يه همگاني سايت بارگذاري مي‌شوند و براي نوارابزارهاي سخنگاه‌ها، مداد‌ها‌ي همگاني يا ساير پلاگين‌ها را تأمين مي‌كنند در صورتي كه پيكربندي‌ مربوطه اجازه‌ي اين كار را بدهد. 
',
	'explication_barre_outils_public_2' => 'مي‌توانيد براي سبك كردن صفحه‌هاي همگاني اين نويسه‌ها (اسكريپت‌ها) را بارگذاري نكنيد. 
در نتيجه پيكربندي سخنگاه‌ها، مدادها و  پلاگين، هرچه باشد نوارابزار چوب قلم به طور خودكار در فضاي همگاني ظاهر نخواهد شد. ',

	// I
	'info_barre_outils_public' => 'نوارابزارهاي همگاني ',
	'info_porte_plume_titre' => 'پيكربندي نوارابزارها',

	// L
	'label_barre_outils_public_non' => 'بارگذاري نكردن نويسه‌هاي نوارابزارها در فضاي همگاني ',
	'label_barre_outils_public_oui' => 'بارگذاري نويسه‌هاي نوارابزارها در فضاي همگاني',

	// V
	'voir' => 'ديدن'
);

==> spip_4.4.7+dfsg.orig.tar.xz: plugins-dist/porte_plume/lang/barreoutils_fa.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/barreoutils?lang_cible=fa
// ** ne pas modifier le fichier **

return [

	// B
	'barre_a_accent_grave' => 'گنجاندن يك A بزرگ با آكسان گراو',
	'barre_adresse' => 'آدرس',
	'barre_aide' => 'استفاده از ميان‌برهاي حروف‌نگاري براي بهبود صفحه‌آرايي ',
	'barre_alignerdroite' => 'پارگراف [/راست‌چين/]',
	'barre_ancres' => 'مديريت نقطه‌ لنگر‌ها',
	'barre_barre' => 'خط زدن متن ',
	'barre_bulle' => 'ابزار نكته',
	'barre_c_cedille_maj' => 'گنجانن يك C سدي بزرگ',
	'barre_cadre' => 'قرار دادن يك <cadre>جاي متن </cadre>',
	'barre_caracteres' => 'كاراكتر‌هاي ويژه',
	'barre_centrer' => 'پارگراف [[وسط چين]]',
	'barre_chercher' => 'جستجوي جايگزين',
	'barre_clean' => 'پاك كردن كد تمام برچسب‌هاي اچ.تي.ام.ال',
	'barre_code' => 'تبديل به فرم <code>كد انفورماتيك</code>',
	'barre_desindenter' => 'حذف تورفتگي‌ يك فهرست',
	'barre_e_accent_aigu' => 'گنحاندن يك E بزرگ با آكسان اگو',
	'barre_e_accent_grave' => 'گنجاندن يك E بزرگ با آكسان گراو',
	'barre_ea' => 'گنجاندن يك E در يك A',
	'barre_ea_maj' => 'گنجاندن يك E در يك  A بزرگ',
	'barre_encadrer' => '[(در كادر گذاري)] پارگراف',
	'barre_eo' => 'گنجاندن يك E در يك I',
	'barre_eo_maj' => 'گنجاندن يكE در يك O',
	'barre_euro' => 'گنحاندن سمبل €',
	'barre_exposant' => 'گذاشتن متن در<sup> انديس بالا </sup>',
	'barre_formatages_speciaux' => 'فرمت سازي ويژه',
	'barre_galerie' => 'باز كردن گالري',
	'barre_gestion_anc_bulle' => 'ابزار نكته‌ي ديگر',
	'barre_gestion_anc_caption' => 'مديريت نقطه‌ لنگرها',
	'barre_gestion_anc_cible' => 'نقطه لنگر هدف',
	'barre_gestion_anc_inserer' => 'نبديل به نقطه لنگر',
	'barre_gestion_anc_nom' => 'نام نقطه لنگر',
	'barre_gestion_anc_pointer' => 'اشاره به يك نقطه لنگر ',
	'barre_gestion_caption' => 'شرح و خلاصه',
	'barre_gestion_colonne' => 'شماره ستون‌ها',
	'barre_gestion_cr_casse' => 'تطابق حالت',
	'barre_gestion_cr_changercasse' => 'تغيير حالت',
	'barre_gestion_cr_changercassemajuscules' => 'تبديل به حرف بزرگ ',
	'barre_gestion_cr_changercasseminuscules' => 'تبديل به حرف بزرگ',
	'barre_gestion_cr_chercher' => 'جستجو',
	'barre_gestion_cr_entier' => 'كلمه‌ي كامل ',
	'barre_gestion_cr_remplacer' => 'جايگزيني',
	'barre_gestion_cr_tout' => 'جايگزيني همه',
	'barre_gestion_entete' => 'سرصفحه',
	'barre_gestion_ligne' => 'بدون پيوند',
	'barre_gestion_taille' => 'اندازه ثابت ',
	'barre_glossaire' => 'مدخل [فرهنگ لغت؟] (ويكيپديا)',
	'barre_gras' => '{{بولد}} سازي',
	'barre_guillemets' => 'در «گيومه» گذاشتن',
	'barre_guillemets_simples' => 'در "تك گيومه" گذاشتن',
	'barre_indenter' => 'تورفتگي يك فهرست',
	'barre_inserer_cadre' => 'كنجاندن يك كد پيش فرمت شده  (cadre)', # MODIF
	'barre_inserer_caracteres' => 'گنجاندن كارآكتر‌هاي ويژه',
	'barre_inserer_code' => 'گنحاندن يك كد افنورماتيك (code)', # MODIF
	'barre_intertitre' => 'تبديل به {{ميان‌تيتر}}',
	'barre_italic' => '{{ايرانيك}}سازي',
	'barre_langue' => 'زبان اختصاري',
	'barre_lien' => 'تبديل به [پيوند هايپرتكس ->http://...[',
	'barre_lien_externe' => 'پيوند بيروني',
	'barre_lien_input' => 'لطفاً نشاني پيوند خود را وارد كنيد (مي‌توانيد يك نشاني اينترنت با فرمت http://www.monsite.com وارد كنيد، يا يك نشاني ايميل، يا خيلي ساده، شماره‌ي مقاله‌ي اين سايت را وارد كنيد). ',
	'barre_liste_ol' => 'تبيدل يه ليست شماره دار',
	'barre_liste_ul' => 'تبديل به فهرست كردن',
	'barre_lorem_ipsum' => 'گنجاندن يك پارگراف بدلي ',
	'barre_lorem_ipsum_3' => 'گنجاندن سه پارگراف بدلي ',
	'barre_miseenevidence' => 'پررنگ ‌سازي*] متن*] ',
	'barre_note' => 'تبديل به [[پانويس]]',
	'barre_paragraphe' => 'ايجاد يك پارگراف',
	'barre_petitescapitales' => 'تبديل متن به  <sc>حروف كاپيتال كوچك</sc>',
	'barre_poesie' => 'ويرايش به مانند  <شعر>شعر</شعر>',
	'barre_preview' => 'حالت پيش‌نمايش ',
	'barre_quote' => '<quote>نقل قول</quote>',
	'barre_stats' => 'نمايش آمارهاي متن ',
	'barre_tableau' => 'گنحاندن/اصلاح كردن (انتخاب از پيش) يك جدول ',

	// C
	'config_info_enregistree' => 'پيكربندي ثبت شده',

	// E
	'editer' => 'ويرايش',
	'explication_barre_outils_public' => 'سي.اس.اس و جاوااسكريپتز براي نوار ابزارها (چوب قلم) در صفحه‌يه همگاني سايت بارگذاري مي‌شوند و براي نوارابزارهاي سخنگاه‌ها، مداد‌ها‌ي همگاني يا ساير پلاگين‌ها را تأمين مي‌كنند در صورتي كه پيكربندي‌ مربوطه اجازه‌ي اين كار را بدهد. 
',
	'explication_barre_outils_public_2' => 'مي‌توانيد براي سبك كردن صفحه‌هاي همگاني اين نويسه‌ها (اسكريپت‌ها) را بارگذاري نكنيد. 
در نتيجه پيكربندي سخنگاه‌ها، مدادها و  پلاگين، هرچه باشد نوارابزار چوب قلم به طور خودكار در فضاي همگاني ظاهر نخواهد شد. ',

	// I
	'info_barre_outils_public' => 'نوارابزارهاي همگاني ',
	'info_porte_plume_titre' => 'پيكربندي نوارابزارها',

	// L
	'label_barre_outils_public_non' => 'بارگذاري نكردن نويسه‌هاي نوارابزارها در فضاي همگاني ',
	'label_barre_outils_public_oui' => 'بارگذاري نويسه‌هاي نوارابزارها در فضاي همگاني',

	// V
	'voir' => 'ديدن',
];
